import logging
from confluent_kafka import ConsumerGroupTopicPartitions
from confluent_kafka.admin import AdminClient

_logger = logging.getLogger(__name__)


class KafkaManager:
    def __init__(self, config):
        bootstrap_server = config.get("kafka", "bootstrap_server")
        port = config.get("kafka", "port")
        kafka_config = {'bootstrap.servers': f'{bootstrap_server}:{port}'}
        self.kafka_admin_client = AdminClient(kafka_config)

    def _get_consumer_groups(self):
        ret = self.kafka_admin_client.list_consumer_groups().result()
        return [group_id.group_id for group_id in ret.valid]

    def get_offsets_all_consumer_groups(self):
        topic_offsets = {}
        for consumer_group in self._get_consumer_groups():
            # Special case to remove "metrics_monitor" consumer group
            if consumer_group != 'metrics_monitor':
                cg_topic_partitions = ConsumerGroupTopicPartitions(group_id=consumer_group)
                ret = \
                    self.kafka_admin_client.list_consumer_group_offsets([cg_topic_partitions])[consumer_group].result()
                for topic in ret.topic_partitions:
                    if topic.topic in topic_offsets:
                        topic_offsets[topic.topic][consumer_group] = topic.offset
                    else:
                        topic_offsets[topic.topic] = {consumer_group: topic.offset}
        return topic_offsets

    def delete_topics(self, topics):
        if len(topics) > 0:
            self.kafka_admin_client.delete_topics(topics)
            _logger.info(f"Deleted {len(topics)} from kafka")
        else:
            _logger.info(f"No topics were passed to delete")
